class ApiService {
    constructor(baseUrl) {
      this.baseUrl = baseUrl;
    }
  
    async fetchData(endpoint, params = {}) {
      try {
        const url = new URL(`${this.baseUrl}/${endpoint}`);
        Object.keys(params).forEach((key) => url.searchParams.append(key, params[key]));
  
        console.log("Fetching data from URL:", url.toString()); // Added logging
  
        const response = await fetch(url);
        if (!response.ok) {
          throw new Error(`Failed to fetch data from ${url}: ${response.statusText}`);
        }
  
        const result = await response.json();
        console.log("Fetched data:", result); // Added logging
        return result.data;
      } catch (error) {
        console.error("API Error:", error.message);
        throw error;
      }
    }
  
    async fetchOrderDetails(orderId) {
      return this.fetchData(`order`, { id_eq: orderId });
    }
  
    async fetchCustomerDetails(customerId) {
      return this.fetchData(`customer`, { id_eq: customerId });
    }
  
    async fetchRestaurantDetails(restaurantId) {
      return this.fetchData(`restaurant`, { id_eq: restaurantId });
    }
  
    async fetchAddressDetails(addressId) {
      return this.fetchData(`address/${addressId}`);
    }
  }
  
  export default new ApiService("https://api.hyperapps.in/api/v2");